# Sorcar-specific instructions:

- Use 'uv run check --full' to lint, typecheck, and format code.
- Run 'uv run pytest -v' with a timeout of 900 seconds to test KISS
- Do NOT try to load the extension from the IDE itself.
